@@ -1,4 +1,4 @@
-import argparse, math, os, sys
+import argparse, math, os, sys, tempfile
 from pathlib import Path
 from shutil import which
 from typing import Dict
@@ -10,8 +10,8 @@ from joblib import Parallel, delayed
 from tinytag import TinyTag
 
 from xklb import subtitle, utils
-from xklb.db import fetchall_dict, optimize_db, sqlite_con
-from xklb.paths import get_media_files, youtube_dl_id
+from xklb.db import connect_db, fetchall_dict, optimize_db
+from xklb.paths import SUB_TEMP_DIR, get_media_files, youtube_dl_id
 from xklb.player import mark_media_deleted
 from xklb.utils import SQLITE_PARAM_LIMIT, cmd, combine, log, safe_unpack
 
@@ -111,7 +111,7 @@ def extract_metadata(args, f):
         except (KeyboardInterrupt, SystemExit):
             exit(130)
         except Exception:
-            print(f"Failed reading {f}", file=sys.stderr)
+            print(f"[{f}] Failed reading header", file=sys.stderr)
             if args.delete_unplayable:
                 if which("trash-put") is not None:
                     cmd("trash-put", f, strict=False)
@@ -120,7 +120,7 @@ def extract_metadata(args, f):
             return
 
         if not "format" in probe:
-            print(f"Failed reading format {f}", file=sys.stderr)
+            print(f"[{f}] Failed reading format", file=sys.stderr)
             print(probe)
             return
 
@@ -233,11 +233,13 @@ def extract_chunk(args, l):
         or []
     )
 
+    [p.unlink() for p in Path(SUB_TEMP_DIR).glob("*.srt")]
+
     DF = pd.DataFrame(list(filter(None, metadata)))
 
     DF.apply(pd.to_numeric, errors="ignore").convert_dtypes().to_sql(  # type: ignore
         "media",
-        con=args.con,
+        con=args.db.conn,
         if_exists="append",
         index=False,
         chunksize=70,
@@ -261,7 +263,7 @@ def find_new_files(args, path):
     try:
         existing = set(
             utils.single_column_tolist(
-                fetchall_dict(args.con, f"select path from media where is_deleted=0 and path like '{path}%'"), "path"
+                fetchall_dict(args.db, f"select path from media where is_deleted=0 and path like '{path}%'"), "path"
             )
         )
     except Exception:
@@ -272,7 +274,7 @@ def find_new_files(args, path):
         deleted_files = list(existing - new_files)
         deleted_count = mark_media_deleted(args, deleted_files)
         if deleted_count > 0:
-            print("Marking", deleted_count, "orphaned metadata records as deleted")
+            print(f"[{path}] Marking", deleted_count, "orphaned metadata records as deleted")
 
     return scanned_files
 
@@ -296,7 +298,7 @@ def scan_path(args, path):
             extract_chunk(args, l)
 
             if args.subtitle:
-                print("Fetching subtitles")
+                print(f"[{path}] Fetching subtitles")
                 Parallel(n_jobs=5)(delayed(subtitle.get)(args, file) for file in l)
 
     return len(new_files)
@@ -304,12 +306,12 @@ def scan_path(args, path):
 
 def extractor(args):
     Path(args.database).touch()
-    args.con = sqlite_con(args.database)
+    args.db = connect_db(args)
     new_files = 0
     for path in args.paths:
         new_files += scan_path(args, path)
 
-    if new_files > 0:
+    if new_files > 0 or args.optimize:
         optimize_db(args)
 
 
