@@ -7,7 +7,7 @@ import ffmpeg, pysubs2
 from ffmpeg import Error
 from joblib import Parallel, delayed
 
-from xklb.paths import get_media_files, youtube_dl_id
+from xklb.paths import SUB_TEMP_DIR, get_media_files, youtube_dl_id
 from xklb.utils import cmd, flatten, log, remove_text_inside_brackets, remove_whitespaace
 
 SUBTITLE_FORMATS = "vtt|srt|ssa|ass|jss|aqt|mpl2|mpsub|pjs|rt|sami|smi|stl|xml|txt|psb|ssf|usf"
@@ -15,7 +15,7 @@ IMAGE_SUBTITLE_CODECS = ["dvbsub", "dvdsub", "pgssub", "xsub", "dvb_subtitle", "
 
 
 def extract(video_file, stream_index):
-    temp_srt = tempfile.mktemp(".srt")
+    temp_srt = tempfile.mktemp(".srt", dir=SUB_TEMP_DIR)
 
     stream_id = "0:" + str(stream_index)
 
@@ -33,7 +33,7 @@ def extract(video_file, stream_index):
 
 
 def convert_to_srt(path):
-    temp_srt = tempfile.mktemp(".srt")
+    temp_srt = tempfile.mktemp(".srt", dir=SUB_TEMP_DIR)
     try:
         ffmpeg.input(path).output(temp_srt).run(quiet=True)
     except Error as e:
@@ -52,7 +52,7 @@ def read_sub_unsafe(path):
 
 
 def read_sub(path):
-    if Path(path).suffix != ".srt":
+    if Path(path).suffix.lower() != ".srt":
         path = convert_to_srt(path)
 
     try:
@@ -85,55 +85,29 @@ def has_internal_subtitle(file):
 
 def get_external(file):
     p = Path(file)
-    for suffix in reversed(p.suffixes):
-        subtitles = [
-            str(sub_p)
-            for sub_p in p.parent.glob(p.stem[: -len(suffix)] + "*")
-            if sub_p.suffix[1:] in SUBTITLE_FORMATS.split("|")
-        ]
 
-        if len(subtitles) > 0:
-            return subtitles
+    subtitles = [
+        str(sub_p) for sub_p in p.parent.glob(p.stem + "*") if sub_p.suffix[1:].lower() in SUBTITLE_FORMATS.split("|")
+    ]
+
+    if len(subtitles) > 0:
+        return subtitles
 
     return []
 
 
-def has_external_subtitle(file):
-    file = Path(file)
-
-    if any(
-        [
-            file.with_suffix("." + ext).exists()
-            or file.with_suffix(".en." + ext).exists()
-            or file.with_suffix(".eng." + ext).exists()
-            for ext in SUBTITLE_FORMATS.split("|")
-        ]
-    ):
-        return True
-
-    if len(file.stem) <= 13:
-        return False
-
-    FORMATSUB_REGEX = re.compile(rf".*\.({SUBTITLE_FORMATS})")
-    for globbed in file.parent.glob(file.stem[:-12] + r".*"):
-        match = FORMATSUB_REGEX.match(str(globbed))
-        if match:
-            return True
-
-    return False
-
-
 def get(args, file):
     try:
-        if has_internal_subtitle(file) or has_external_subtitle(file):
+        if has_internal_subtitle(file) or len(get_external(file)) > 0:
             return
     except Exception:
         pass
 
     try:
         yt_video_id = youtube_dl_id(file)
-    except Exception:
+    except Exception as e:
         print(file)
+        print(e)
         return
 
     run_subliminal = not args.youtube_only
@@ -153,7 +127,7 @@ def get(args, file):
         )
 
     if run_subliminal:
-        print("Downloading subtitles:", file)
+        print(f"[{file}] Downloading subtitles")
         cmd(
             "subliminal",
             "--opensubtitles",
