@@ -1,9 +1,10 @@
 import argparse
 from time import sleep
+from typing import Dict
 
 import pandas as pd
 
-from xklb.db import sqlite_con
+from xklb.db import connect_db
 from xklb.player import generic_player, mark_media_watched, override_sort, printer
 from xklb.tabs_extract import Frequency
 from xklb.utils import SC, cmd, dict_filter_bool, flatten, log
@@ -79,15 +80,11 @@ def construct_tabs_query(args):
     return query, bindings
 
 
-def play(args, media: pd.DataFrame):
-    for m in media.to_records():
-        media_file = m["path"]
+def play(args, m: Dict):
+    media_file = m["path"]
 
-        cmd(*generic_player(args), media_file, strict=False)
-        mark_media_watched(args, media_file)
-
-        if len(media) > 10:
-            sleep(0.3)
+    cmd(*generic_player(args), media_file, strict=False)
+    mark_media_watched(args, media_file)
 
 
 def frequency_filter(args, media: pd.DataFrame):
@@ -98,7 +95,7 @@ def frequency_filter(args, media: pd.DataFrame):
         Frequency.Quarterly.value: 91,
         Frequency.Yearly.value: 365,
     }
-    counts = args.con.execute("select frequency, count(*) from media group by 1").fetchall()
+    counts = args.db.execute("select frequency, count(*) from media group by 1").fetchall()
     for freq, freq_count in counts:
         num_days = mapper.get(freq, 365)
         num_tabs = max(1, freq_count // num_days)
@@ -111,20 +108,23 @@ def frequency_filter(args, media: pd.DataFrame):
 
 
 def process_tabs_actions(args, construct_tabs_query):
-    args.con = sqlite_con(args.database)
+    args.db = connect_db(args)
     query, bindings = construct_tabs_query(args)
 
     if args.print:
         return printer(args, query, bindings)
 
-    media = pd.DataFrame([dict(r) for r in args.con.execute(query, bindings).fetchall()])
+    media = pd.DataFrame(args.db.query(query, bindings))
     if len(media) == 0:
         print("No media found")
         exit(2)
 
     media = frequency_filter(args, media)
 
-    play(args, media)
+    for m in media.to_records():
+        play(args, m)
+    if len(media) > 10:
+        sleep(0.3)
 
 
 def parse_args(action, default_db):
